/*
 * JLabelBeanInfoSwingBeanInfo.template	1.4 98/04/13
 * 
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 * 
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 */

package com.sun.java.swing;

import com.sun.java.swing.beaninfo.SwingBeanInfo;

import java.beans.BeanDescriptor;
import java.beans.PropertyDescriptor;
import java.awt.Image;


/**
 * Descriptive information about the JLabel class for Java 
 * Beans application builders.  This BeanInfo class provides descriptions
 * of each property, of the bean itself, it indicates which
 * JLabel properties are bound, and it provides other
 * information and icons useful to builders.
 * 
 * @version 1.4 04/13/98
 * @author <your name here>
 */

public class JLabelBeanInfo extends SwingBeanInfo 
{
    private static final Class classJLabel = com.sun.java.swing.JLabel.class;

    /**
     * @return a JLabel BeanDescriptor
     */
    public BeanDescriptor getBeanDescriptor() {
	return createBeanDescriptor(classJLabel, new Object[] {
				PREFERRED, Boolean.TRUE,
				              "isContainer",Boolean.FALSE,
     
			        SHORTDESCRIPTION, "A component that displays a short string and an icon."
	    }			    
        );            	       		    
    }


    /**
     * Create a JLabel PropertyDescriptor.  This is just an internal
     * convenience method that allows one to leave the JLabel.class
     * argument out of the createPropertyDescriptor() class in the 
     * getPropertyDescriptors() method below.
     * 
     * @param name the name of the property
     * @param args an array java.beans.PropertyDescriptor property names and values
     * @return a JLabel PropertyDescriptor.
     * @see SwingBeanInfo#createPropertyDescriptor
     */
    private PropertyDescriptor createPropertyDescriptor(String name, Object[] args) {
	return super.createPropertyDescriptor(classJLabel, name, args);
    }


    /**
     * This method returns a list of bean PropertyDescriptors, one for each public
     * property in JLabel.  The first property is the "default" property.
     *
     * @return a complete list of bean PropertyDescriptors for JLabel
     * @see SwingBeanInfo
     * @see java.beans.BeanInfo#getDefaultPropertyIndex
     */
    public PropertyDescriptor[] getPropertyDescriptors() 
    {
         
	return new PropertyDescriptor[] {
            
             createPropertyDescriptor("icon", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "The icon this component will display.",
               }
             ),
             
             createPropertyDescriptor("horizontalTextPosition", new Object[] {
                           EXPERT, Boolean.TRUE,
                 SHORTDESCRIPTION, "The horizontal position of the label's text, relative to its image.",
               }
             ),
             
             createPropertyDescriptor("UIClassID", new Object[] {
                 SHORTDESCRIPTION, "UIClassID",
               }
             ),
             
             createPropertyDescriptor("accessibleContext", new Object[] {
                           EXPERT, Boolean.TRUE,
                 SHORTDESCRIPTION, "The AccessibleContext associated with this Label.",
               }
             ),
             
             createPropertyDescriptor("UI", new Object[] {
                           EXPERT, Boolean.TRUE,
                 SHORTDESCRIPTION, "The L&F object that renders this component.",
               }
             ),
             
             createPropertyDescriptor("disabledIcon", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "The value of the disabledIcon property if it has been set.",
               }
             ),
             
             createPropertyDescriptor("verticalTextPosition", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "The vertical position of the text relative to it's image.",
               }
             ),
             
             createPropertyDescriptor("displayedMnemonic", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "The keycode that indicates a mnemonic key.",
               }
             ),
             
             createPropertyDescriptor("text", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "Defines the single line of text this component will display.",
               }
             ),
             
             createPropertyDescriptor("iconTextGap", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "If both the icon and text properties are set, this property defines the space between them.",
               }
             ),
             
             createPropertyDescriptor("labelFor", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "The component this is labelling.",
               }
             ),
             
             createPropertyDescriptor("horizontalAlignment", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "The alignment of the label's content along the X axis.",
               }
             ),
             
             createPropertyDescriptor("verticalAlignment", new Object[] {
                            BOUND, Boolean.TRUE,
                 SHORTDESCRIPTION, "The alignment of the label's contents along the Y axis.",
               }
             )
             
	};
    }


    /**
     * @return an icon of the specified kind for JLabel
     */
    public Image getIcon(int kind) {
	Image i;
	switch (kind){
	  case ICON_COLOR_32x32:
	          i = loadImage("beaninfo/images/JLabelColor32.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentColor32.gif") : i);
	  case ICON_COLOR_16x16:
		  i = loadImage("beaninfo/images/JLabelColor16.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentColor16.gif") : i);
	  case ICON_MONO_32x32:
		  i = loadImage("beaninfo/images/JLabelMono32.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentMono32.gif") : i);		  
	  case ICON_MONO_16x16:
		  i = loadImage("beaninfo/images/JLabelMono16.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentMono16.gif") : i);		  
	  default:
	    return super.getIcon(kind);
	}
    }
}


